==> blesta-5.10.2.zip: blesta/language/uk_ua/logs.php <==
<?php
/**
 * Logs
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Logs.!error.end_date.format'] = 'Неправильний формат дати завершення.';
$lang['Logs.!error.start_date.format'] = 'Неправильний формат дати початку.';
$lang['Logs.!error.group.betweenlength'] = 'Група повинна мати довжину від 1 до 32 символів.';
$lang['Logs.!error.group.unique'] = 'Ідентифікатор та групу завдання cron вже взято.';
$lang['Logs.!error.event.maxlength'] = 'Довжина події не може перевищувати 32 символів.';
$lang['Logs.!error.run_id.exists'] = 'Неправильний ідентифікатор завдання cron.';
$lang['Logs.!error.last_name.empty'] = 'Прізвище не повинно бути порожнім.';
$lang['Logs.!error.first_name.empty'] = 'Ім\'я не повинно бути порожнім.';
$lang['Logs.!error.account_id.empty'] = 'Відсутній ідентифікатор облікового запису.';
$lang['Logs.!error.account_type.format'] = 'Неправильний тип облікового запису.';
$lang['Logs.!error.type.format'] = 'Неправильний тип.';
$lang['Logs.!error.staff_id.empty'] = 'Відсутнє посвідчення персоналу.';
$lang['Logs.!error.date_changed.valid'] = 'Змінено недійсну дату.';
$lang['Logs.!error.by_user_id.exists'] = 'Недійсний за ідентифікатором користувача.';
$lang['Logs.!error.fields.empty'] = 'Відсутні поля для запису.';
$lang['Logs.!error.client_id.exists'] = 'Невірний ідентифікатор клієнта.';
$lang['Logs.!error.contact_id.empty'] = 'Відсутній контактний номер.';
$lang['Logs.!error.success.format'] = 'Неправильне значення успіху.';
$lang['Logs.!error.messenger_id.exists'] = 'Невірний ідентифікатор месенджера.';
$lang['Logs.!error.to_user_id.exists'] = 'Неправильний ідентифікатор користувача.';
$lang['Logs.!error.result.format'] = 'Результатом входу має бути або "успіх", або "невдача".';
$lang['Logs.!error.user_log_exists.empty'] = 'Користувача за даною IP-адресою не існує.';
$lang['Logs.!error.ip_address.length'] = 'Довжина IP-адреси не може перевищувати 39 символів.';
$lang['Logs.!error.ip_address.empty'] = 'Відсутня IP-адреса.';
$lang['Logs.!error.user_id.empty'] = 'Відсутній ідентифікатор користувача.';
$lang['Logs.!error.group.maxlength'] = 'Довжина групи не може перевищувати 8 символів.';
$lang['Logs.!error.group.empty'] = 'Зникла група.';
$lang['Logs.!error.status.format'] = 'Неправильний тип статусу.';
$lang['Logs.!error.url.empty'] = 'Невірна адреса.';
$lang['Logs.!error.direction.format'] = 'Неправильний тип напрямку.';
$lang['Logs.!error.gateway_id.exists'] = 'Неправильний ідентифікатор шлюзу.';
$lang['Logs.!error.module_id.exists'] = 'Невірний ідентифікатор модуля.';
$lang['Logs.!error.staff_id.exists'] = 'Недійсне посвідчення працівника.';
$lang['Logs.!error.sent.length'] = 'Довжина повідомлення не може перевищувати 1 символ.';
$lang['Logs.!error.sent.format'] = 'Надіслане має бути числом.';
$lang['Logs.!error.subject.empty'] = 'Не вистачає предмета.';
$lang['Logs.!error.from_name.empty'] = 'Не вистачає "а" в імені.';
$lang['Logs.!error.from_address.empty'] = 'Не вистачає "від".';
$lang['Logs.!error.to_address.empty'] = 'Не вистачає адреси.';
$lang['Logs.!error.company_id.exists'] = 'Невірний ідентифікатор компанії.';
$lang['Logs.!error.deletelog_datetime'] = 'Неправильний формат дати.';

==> blesta-5.11.4.zip: blesta/language/uk_ua/logs.php <==
<?php
/**
 * Logs
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Logs.!error.end_date.format'] = 'Неправильний формат дати завершення.';
$lang['Logs.!error.start_date.format'] = 'Неправильний формат дати початку.';
$lang['Logs.!error.group.betweenlength'] = 'Група повинна мати довжину від 1 до 32 символів.';
$lang['Logs.!error.group.unique'] = 'Ідентифікатор та групу завдання cron вже взято.';
$lang['Logs.!error.event.maxlength'] = 'Довжина події не може перевищувати 32 символів.';
$lang['Logs.!error.run_id.exists'] = 'Неправильний ідентифікатор завдання cron.';
$lang['Logs.!error.last_name.empty'] = 'Прізвище не повинно бути порожнім.';
$lang['Logs.!error.first_name.empty'] = 'Ім\'я не повинно бути порожнім.';
$lang['Logs.!error.account_id.empty'] = 'Відсутній ідентифікатор облікового запису.';
$lang['Logs.!error.account_type.format'] = 'Неправильний тип облікового запису.';
$lang['Logs.!error.type.format'] = 'Неправильний тип.';
$lang['Logs.!error.staff_id.empty'] = 'Відсутнє посвідчення персоналу.';
$lang['Logs.!error.date_changed.valid'] = 'Змінено недійсну дату.';
$lang['Logs.!error.by_user_id.exists'] = 'Недійсний за ідентифікатором користувача.';
$lang['Logs.!error.fields.empty'] = 'Відсутні поля для запису.';
$lang['Logs.!error.client_id.exists'] = 'Невірний ідентифікатор клієнта.';
$lang['Logs.!error.contact_id.empty'] = 'Відсутній контактний номер.';
$lang['Logs.!error.success.format'] = 'Неправильне значення успіху.';
$lang['Logs.!error.messenger_id.exists'] = 'Невірний ідентифікатор месенджера.';
$lang['Logs.!error.to_user_id.exists'] = 'Неправильний ідентифікатор користувача.';
$lang['Logs.!error.result.format'] = 'Результатом входу має бути або "успіх", або "невдача".';
$lang['Logs.!error.user_log_exists.empty'] = 'Користувача за даною IP-адресою не існує.';
$lang['Logs.!error.ip_address.length'] = 'Довжина IP-адреси не може перевищувати 39 символів.';
$lang['Logs.!error.ip_address.empty'] = 'Відсутня IP-адреса.';
$lang['Logs.!error.user_id.empty'] = 'Відсутній ідентифікатор користувача.';
$lang['Logs.!error.group.maxlength'] = 'Довжина групи не може перевищувати 8 символів.';
$lang['Logs.!error.group.empty'] = 'Зникла група.';
$lang['Logs.!error.status.format'] = 'Неправильний тип статусу.';
$lang['Logs.!error.url.empty'] = 'Невірна адреса.';
$lang['Logs.!error.direction.format'] = 'Неправильний тип напрямку.';
$lang['Logs.!error.gateway_id.exists'] = 'Неправильний ідентифікатор шлюзу.';
$lang['Logs.!error.module_id.exists'] = 'Невірний ідентифікатор модуля.';
$lang['Logs.!error.staff_id.exists'] = 'Недійсне посвідчення працівника.';
$lang['Logs.!error.sent.length'] = 'Довжина повідомлення не може перевищувати 1 символ.';
$lang['Logs.!error.sent.format'] = 'Надіслане має бути числом.';
$lang['Logs.!error.subject.empty'] = 'Не вистачає предмета.';
$lang['Logs.!error.from_name.empty'] = 'Не вистачає "а" в імені.';
$lang['Logs.!error.from_address.empty'] = 'Не вистачає "від".';
$lang['Logs.!error.to_address.empty'] = 'Не вистачає адреси.';
$lang['Logs.!error.company_id.exists'] = 'Невірний ідентифікатор компанії.';
$lang['Logs.!error.deletelog_datetime'] = 'Неправильний формат дати.';
$lang['Logs.!error.new_service.format'] = 'Новий сервіс повинен бути масивом.';
$lang['Logs.!error.old_service.format'] = 'Старий сервіс повинен бути масивом.';
$lang['Logs.!error.transactions.exists'] = 'Одна або декілька транзакцій не існують.';
$lang['Logs.!error.transaction_id.format'] = 'Транзакції повинні бути масивом.';
$lang['Logs.!error.service_id.exists'] = 'Невірний ідентифікатор послуги.';
